@@ -27,34 +27,41 @@ def create(lang: Lang, cna_graph: CnaGraph) -> List["ComplexityIndex"]:
     from rb.complexity.word.valence_type import ValenceTypeEnum
 
     indices = []
-
-    text_elements = [TextElementType.WORD.value, TextElementType.SENT.value, TextElementType.BLOCK.value, TextElementType.DOC.value]
-    measure_functions = [MeasureFunction.AVG, MeasureFunction.STDEV, MeasureFunction.MAX]
-    indices_classes = [WdLen, WdSyllab, WdDiffLemma, NoRepetitions, WdMaxDpthHypTree, WdAvgDpthHypTree, NoWdPathsHypTree, Polysemy]
     
-    for index_class in indices_classes:
-        for text_element in text_elements:
-            for measure_function in measure_functions:
-                indices.append(index_class(lang, text_element, measure_function))
+    text_elements = [TextElementType.WORD.value, TextElementType.SENT.value, TextElementType.BLOCK.value]
+    measure_functions = [MeasureFunction.AVG, MeasureFunction.STDEV, MeasureFunction.MAX]
+    word_indices = [WdLen, WdSyllab, WdDiffLemma, WdMaxDpthHypTree, WdAvgDpthHypTree, NoWdPathsHypTree, Polysemy]
+    
+    for index_class in word_indices:
+        for measure_function in measure_functions:
+            indices.append(index_class(lang, TextElementType.WORD.value, measure_function))
 
     if lang is Lang.EN:
         for at in AoaTypeEnum:
             for text_element in text_elements:
                 for measure_function in measure_functions:
                     indices.append(Aoa(lang, at, text_element, measure_function))
+            indices.append(Aoa(lang, at, TextElementType.DOC.value, MeasureFunction.IDENTITY))
         for at in AoeTypeEnum:
             for text_element in text_elements:
                 for measure_function in measure_functions:
                     indices.append(Aoe(lang, at, text_element, measure_function))
+            indices.append(Aoe(lang, at, TextElementType.DOC.value, MeasureFunction.IDENTITY))
         for vt in ValenceTypeEnum:
             for text_element in text_elements:
                 for measure_function in measure_functions:
                     indices.append(Valence(lang, vt, text_element, measure_function))
+            indices.append(Valence(lang, vt, TextElementType.DOC.value, MeasureFunction.IDENTITY))
 
     for named_ent_type in NamedEntityONEnum:
-        for text_element in text_elements:
-                for measure_function in measure_functions:
-                    indices.append(NoNamedEntity(lang, named_ent_type=named_ent_type, reduce_depth=text_element, 
-                                        reduce_function=measure_function))
-    
+        for text_element in text_elements[1:]:
+            for measure_function in measure_functions:
+                indices.append(NoNamedEntity(lang, named_ent_type=named_ent_type, reduce_depth=text_element, 
+                                    reduce_function=measure_function))
+        indices.append(NoNamedEntity(lang, named_ent_type=named_ent_type, reduce_depth=TextElementType.DOC.value, 
+                                        reduce_function=MeasureFunction.IDENTITY))
+    for text_element in text_elements[1:]:
+        for measure_function in measure_functions:
+            indices.append(NoRepetitions(lang, reduce_depth=text_element, reduce_function=measure_function))
+        indices.append(NoRepetitions(lang, reduce_depth=TextElementType.DOC.value, reduce_function=MeasureFunction.IDENTITY))
     return indices
\ No newline at end of file
